#!/usr/bin/env python3

import subprocess
import sys

from charmhelpers.core.hookenv import (
    config,
    log,
    status_set
)
from charmhelpers.core.templating import render

status_set('maintenance', 'Getting config elements')

# Get global config and get cidr and gateway
cfg = config()
cidr = cfg.get('cidr')
gateway = cfg.get('gateway')

if cidr is None or gateway is None:
    status_set('blocked', 'cidr and gateway must be set in charm config')

service = 'charm-pre-install-policy-routing'
table = '100'
priority = '100'

cmd = 'ip rule list | grep {}'.format(table)
try:
    ip_rule = subprocess.check_output(cmd, shell=True)
    log('Found rule: {}. Exiting'.format(ip_rule))
    status_set('active', 'Unit ready')
    sys.exit(0)
except subprocess.CalledProcessError:
    # grep exits with 1 if not match found -> CalledProcessError
    # it means that no match was found -> we create the service
    log('No rule found. Creating service')
    status_set('maintenance', 'Creating service')

service_file = '/etc/systemd/system/{}.service'.format(service)
service_template = 'service.j2'
context = {
    'gateway': gateway,
    'table': table,
    'cidr': cidr,
    'priority': priority
}
# Render the service template
render(service_template, service_file, context, perms=0o755)

# Enable and start the one-shot service
cmd = 'systemctl enable {}'.format(service)
subprocess.check_call(cmd, shell=True)
cmd = 'systemctl start {}'.format(service)
subprocess.check_call(cmd, shell=True)

status_set('active', 'Unit ready')
